@@ -122,7 +122,7 @@
     (modify-frame-parameters (selected-frame)
 			     (list (cons 'riece-window-configuration
 					 (current-window-configuration))))
-    (if entry
+    (if (cdr entry)
 	(set-window-configuration (cdr entry))
       (delete-other-windows))
     (message
@@ -144,6 +144,13 @@ the layout to the selected layout-name."
 	riece-save-variables-are-dirty t)
   (riece-command-configure-windows))
 
+(defun riece-command-toggle-others-buffer-mode ()
+  (interactive)
+  (setq riece-others-buffer-mode
+	(not riece-others-buffer-mode)
+	riece-save-variables-are-dirty t)
+  (riece-command-configure-windows))
+
 (defun riece-command-toggle-user-list-buffer-mode ()
   (interactive)
   (setq riece-user-list-buffer-mode
@@ -187,7 +194,8 @@ the layout to the selected layout-name."
 				0)))))
   (riece-send-string (format "TOPIC %s :%s\r\n"
 			     (riece-identity-prefix riece-current-channel)
-			     topic)))
+			     topic)
+		     riece-current-channel))
 
 (defun riece-command-invite (user)
   (interactive
@@ -220,7 +228,8 @@ the layout to the selected layout-name."
 	       user message)
      (format "KICK %s %s\r\n"
 	     (riece-identity-prefix riece-current-channel)
-	     user))))
+	     user))
+   riece-current-channel))
 
 (defun riece-command-names (pattern)
   (interactive
@@ -378,14 +387,16 @@ the layout to the selected layout-name."
 	(riece-send-string
 	 (format "NOTICE %s :%s\r\n"
 		 (riece-identity-prefix riece-current-channel)
-		 message))
+		 message)
+	 riece-current-channel)
 	(riece-display-message
 	 (riece-make-message (riece-current-nickname) riece-current-channel
 			     message 'notice t)))
     (riece-send-string
      (format "PRIVMSG %s :%s\r\n"
 	     (riece-identity-prefix riece-current-channel)
-	     message))
+	     message)
+     riece-current-channel)
     (riece-display-message
      (riece-make-message (riece-current-nickname) riece-current-channel
 			 message nil t))))
@@ -424,7 +435,8 @@ the layout to the selected layout-name."
 	       (riece-line-beginning-position)
 	       (riece-line-end-position))))
     (riece-send-string
-     (format "PRIVMSG %s :%s\r\n" (riece-identity-prefix user) text))
+     (format "PRIVMSG %s :%s\r\n" (riece-identity-prefix user) text)
+     user)
     (riece-display-message
      (riece-make-message (riece-current-nickname) user text nil t)))
   (let ((next-line-add-newlines t))
@@ -435,13 +447,13 @@ the layout to the selected layout-name."
     (unless process
       (error "%s" (substitute-command-keys
 		   "Type \\[riece-command-open-server] to open server.")))
-    (riece-process-send-string process
-			       (if key
-				   (format "JOIN %s :%s\r\n"
-					   (riece-identity-prefix target)
-					   key)
-				 (format "JOIN %s\r\n"
-					 (riece-identity-prefix target))))))
+    (riece-send-string (if key
+			   (format "JOIN %s :%s\r\n"
+				   (riece-identity-prefix target)
+				   key)
+			 (format "JOIN %s\r\n"
+				 (riece-identity-prefix target)))
+		       target)))
 
 (defun riece-command-join-partner (target)
   (let ((pointer (riece-identity-member target riece-current-channels)))
@@ -473,15 +485,15 @@ the layout to the selected layout-name."
 
 (defun riece-command-part-channel (target message)
   (let ((process (riece-server-process (riece-identity-server target))))
-    (riece-process-send-string process
-			       (if message
-				   (format "PART %s :%s\r\n"
-					   (riece-identity-prefix target)
-					   message)
-				 (format "PART %s\r\n"
-					 (riece-identity-prefix target))))))
+    (riece-send-string (if message
+			   (format "PART %s :%s\r\n"
+				   (riece-identity-prefix target)
+				   message)
+			 (format "PART %s\r\n"
+				 (riece-identity-prefix target)))
+		       target)))
 
-(defun riece-command-part (target)
+(defun riece-command-part (target &optional message)
   (interactive
    (progn
      (riece-check-channel-commands-are-usable)
