@@ -71,6 +71,8 @@
 (defvar riece-channel-obarray-size 103
   "The size of obarray used by riece on channelname space.")
 
+(defvar riece-addon-dependencies nil)
+
 ;;; Variables local to the server buffers:
 (defvar riece-server-name nil
   "The name of the server.
@@ -146,6 +148,7 @@ Local to the channel buffers.")
 Local to the channel buffers.")
 
 ;;; Modeline indicators:
+(defvar riece-mode-line-buffer-identification nil)
 (defvar riece-channel-indicator "None"
   "String displayed on the modeline to indicate the current channel.")
 (defvar riece-long-channel-indicator "None"
@@ -182,6 +185,8 @@ user's status on the current channel.")
   "Buffer for messages arrived in the current channel.")
 (defvar riece-temp-buffer nil
   "Buffer for temporally use.")
+(defvar riece-debug-buffer nil
+  "Buffer for debug output.")
 
 (defvar riece-buffer-list nil)
 (defvar riece-overriding-server-name nil)
